library(testthat)
library(mitre)

test_check("mitre")
